package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0,````````````"``\````!``$:8````#0``+30```"$``T`"``
M!P`H`!T`'`````8````T``$`-``!`#0```#@````X`````0````$`````P``
M`10``0$4``$!%`````T````-````!`````$````!```````!`````0````"E
M&```I1@````%```0``````$``+````&P```!L`````.(```#P`````<``!``
M`````@``L"@``;`H``&P*````/@```#X````!@````0````$```!)``!`20`
M`0$D````1````$0````$````!&1TY5$`````````````````````````````
M``<````0+VQI8B]L9"YS;RXQ``````````0````4`````T=.50#UL@4Y5D<,
M7A7M4L'DQ#/6$%!U9P````0````0`````4=.50```````````P````(`````
M````0P```&```````````````%<````(````(0```#H`````````-P``````
M```X````.P```#X````U````5@```%,````S````*``````````J````7@``
M````````````)````!<```!=`````P```$\```!<````3@```$H`````````
M````````````````1````!\``````````````$<````R`````````",`````
M````/0```%L````B````#@```%D`````````10```$D````E`````````%H`
M```Q````+`````L`````````/````%4```!0````-@```!T````_````+P``
M`"X```!!````````````````````````````````````````````````````
M!P````````````````````````````````````\`````````#0````0```!8
M````````````````````#``````````)````&0```!4`````````$0```!(`
M```%```````````````8````1@`````````;`````````!X```!1````````
M`$`````````````````````*`````````#````!(`````@```$,`````````
M&@```$P````F````0@````````!4````-````"T````Y`````````!,```!?
M```````````````I````````````````````````````````````%````"<`
M``!+````*P```!P``````````````````````````````"``````````4@``
M``8````````````````````6````30````$````0````$0```#\````(````
M"`00'`""!$`E!```*(0`AJ`"((&"*`0H2T,2@#A(1`"*`````````#\```!"
M````10```$8```!/````4````%,`````````5@```%<```!8````6@```%L`
M``!>```````````?W\5N+4?>SGR:?VNVF\4N#N3_('S49-4<6''9`<9'XH?7
M^D+`XTNL'=/;\GR2X[HL/^7"8&RA^F^+`;*;PT^9UD,):T"<N<1FS*]FL:#6
M_QR+\CCLU45"TW`'B>W;8C/,)8P5"Y<Z#&NCW:>;G*E_"@*GX%">&FICX36!
M5Q"*"DG[X*,````````````````````````"=0``````````$@```````L4`
M`````````!(```````(/```````````2```````"8P``````````$@``````
M`@0``````````!(````````0```````````@```````#/@``````````$@``
M`````>@``````````!(```````#_```````````2```````!P@``````````
M$@```````KX``````````!(```````%C```````````2```````!_@``````
M````$@```````)T``````````!(```````*:```````````2````````^@``
M````````$@```````K```````````!(```````(_```````````2```````!
M50``````````$@```````2,``````````!(```````!Y```````````6````
M```!D0``````````$@```````C8``````````!(```````+O```````````2
M```````!L```````````$@```````7X``````````!(```````(>````````
M```2```````!X0``````````$@```````8H``````````!(```````$Q````
M```````2`````````0``````````(@```````:L``````````!(```````*3
M```````````2```````!]P``````````$@```````&H``````````!(`````
M``'2```````````2````````K```````````$@```````LP``````````!(`
M``````"X```````````2```````!2@``````````$@```````@D`````````
M`!(```````*A```````````2```````!$```````````$@```````HP`````
M`````!(```````!&```````````2```````!!```````````$@```````7,`
M`````````!(```````#I```````````2```````"MP``````````$@``````
M`?```````````!(```````(E```````````2````````C```````````$@``
M`````,T``````````!(```````%!```````````2```````!V0``````````
M$@```````;@``````````!(```````+=```````````2```````"50``````
M````$@```````"P``````````"````````')```````````2```````"J```
M````````$@```````D<``````````!(```````-'``$X"````,@2```-```#
M<P`!+OP```;D$@``#0```G```1@@```"0!(```T```,;``$C6````!02```-
M```#]P`!(VP```)0$@``#0``!#X``37@```"*!(```T```/C``&SD``````0
M```9```#6@`!);P````T$@``#0```X```5SD```!A!(```T```.8``%AQ```
M``01```/```!G``!L!`````3$0``%````\<``;/``````!```!D```/O``$B
M5````$02```-```$!``!+D0```"X$@``#0``!!8``2O$````1!(```T```0D
M``$L"````$02```-```#BP`!L2``````$```%@```N4``;.0````!!$``!D`
M``-G``$E\````002```-```$+``!L2``````$0``%@```H4``;.@````!!$`
M`!D```-3``&SB``````0```8```#O0`!L30````$$0``%@```Y$``1I@````
M2!(```T```0U``%<2````)P2```-```#C0`!L2``````(```%@```N<``;.0
M````!"$``!D```,L``$N&````"P2```-```#IP`!(I@```#`$@``#0```]D`
M`5YH```!O!(```T```!4``&S;``````1`/_Q````W``!LZ0````!$0``&0``
M`\P``2;T```$T!(```T`7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S
M>7-?=&5R;0!?1TQ/0D%,7T]&1E-%5%]404),15\`4&5R;%]S>7-?:6YI=#,`
M4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?
M9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``97AI=`!L<V5E
M:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`
M=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`&UK9&ER
M`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T-C1?=&EM938T`')E861L
M:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`%]?;&EB
M8U]S=&%R=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S=&1E<G(`;65M8VAR`'-T
M<F-H<@!M96UC;7``;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC
M<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`
M7U]R96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!P
M87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]E9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I;E]U
M<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!M>5]P87)?<&P`7V5N9`!P87)?
M:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I
M;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R7V1I
M90`D9VQO8F%L)`!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)
M0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR`$=,24)#7S(N,S0`````
M``(``P`$``(``P`!``,``P`#``,``P`!``,``0`#``$``P`#``$``0`!``$`
M`P`%``,``0`#``,``P`!``$``P`#``,``0`#``$``P`!``$``P`#``$``P`!
M``$``0`!``,``P`"``$``0`!``,``P`#``0``0`#``,`!``!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``P`!``$``P`!``$``0`!``$``P`!
M``$``0`!``$``0````$`!````Q$````0``````EI&7(````%```$5````!`)
M:1ET````!```!&`````0#6EI$@````,```1L````$`:6D;0````"```$=@``
M`````;-\```5F0```````;`0``!)@````````;.0``!0@````````;.@``!3
M@````````;.D``!>@````````;%8```!@0```````;%@```"@0```````;%H
M```#@0```````;%P```$@0```````;%X```%@0```````;&````&@0``````
M`;&(```'@0```````;&0```(@0```````;&8```)@0```````;&@```*@0``
M`````;&H```+@0```````;&P```,@0```````;&X```-@0```````;'````.
M@0```````;'(```/@0```````;'0```0@0```````;'8```1@0```````;'@
M```2@0```````;'H```3@0```````;'P```4@0```````;'X```6@0``````
M`;(````7@0```````;((```8@0```````;(0```9@0```````;(8```:@0``
M`````;(@```;@0```````;(H```<@0```````;(P```=@0```````;(X```>
M@0```````;)````?@0```````;)(```@@0```````;)0```A@0```````;)8
M```B@0```````;)@```C@0```````;)H```D@0```````;)P```E@0``````
M`;)X```F@0```````;*````G@0```````;*(```H@0```````;*0```I@0``
M`````;*8```J@0```````;*@```K@0```````;*H```L@0```````;*P```M
M@0```````;*X```N@0```````;+````O@0```````;+(```P@0```````;+0
M```Q@0```````;+8``!!@0```````;+@```R@0```````;+H```S@0``````
M`;+P```T@0```````;+X```U@0```````;,````V@0```````;,(```W@0``
M`````;,0```X@0```````;,8```Y@0```````;,@```Z@0```````;,H```[
M@0```````;,P```\@0```````;,X``!$@0```````;-````]@0```````;-(
M```^@0````!KPC_9;\0`@&O3/\%+PC]9"`0"4^A`P`!/Q#^!*V```#0V`X`.
MP!"5ZJ#```[($),K8```-#8"4`[`$)7JH,``#L@0DRM@```T-@#@#L`0E>J@
MP``.R!"3*V```#0V`3`.P!"5ZJ#```[($),K8```-#8"T`[`$)7JH,``#L@0
MDRM@```T-@#P#L`0E>J@P``.R!"3*V```#0V`L`.P!"5ZJ#```[($),K8```
M-#8`L`[`$)7JH,``#L@0DRM@```T-@%`#L`0E>J@P``.R!"3*V```#0V!``.
MP!"5ZJ#```[($),K8```-#8`<`[`$)7JH,``#L@0DRM@```T-@+@#L`0E>J@
MP``.R!"3*V```#0V`T`.P!"5ZJ#```[($),K8```-#8",`[`$)7JH,``#L@0
MDRM@```T-@&`#L`0E>J@P``.R!"3*V```#0V`5`.P!"5ZJ#```[($),K8```
M-#8!T`[`$)7JH,``#L@0DRM@```T-@"@#L`0E>J@P``.R!"3*V```#0V`S`.
MP!"5ZJ#```[($),K8```-#8$4`[`$)7JH,``#L@0DRM@```T-@1`#L`0E>J@
MP``.R!"3*V```#0V`6`.P!"5ZJ#```[($),K8```-#8`T`[`$)7JH,``#L@0
MDRM@```T-@,@#L`0E>J@P``.R!"3*V```#0V`(`.P!"5ZJ#```[($),K8```
M-#8!<`[`$)7JH,``#L@0DRM@```T-@$0#L`0E>J@P``.R!"3*V```#0V`H`.
MP!"5ZJ#```[($),K8```-#8#X`[`$)7JH,``#L@0DRM@```T-@/0#L`0E>J@
MP``.R!"3*V```#0V`0`.P!"5ZJ#```[($),K8```-#8"D`[`$)7JH,``#L@0
MDRM@```T-@/P#L`0E>J@P``.R!"3*V```#0V`O`.P!"5ZJ#```[($),K8```
M-#8#P`[`$)7JH,``#L@0DRM@```T-@-@#L`0E>J@P``.R!"3*V```#0V`?`.
MP!"5ZJ#```[($),K8```-#8!X`[`$)7JH,``#L@0DRM@```T-@.P#L`0E>J@
MP``.R!"3*V```#0V`K`.P!"5ZJ#```[($),K8```-#8!D`[`$)7JH,``#L@0
MDRM@```T-@-0#L`0E>J@P``.R!"3*V```#0V!"`.P!"5ZJ#```[($),K8```
M-#8!H`[`$)7JH,``#L@0DRM@```T-@&P#L`0E>J@P``.R!"3*V```#0V`Q`.
MP!"5ZJ#```[($),K8```-#8"$`[`$)7JH,``#L@0DRM@```T-@'`#L`0E>J@
MP``.R!"3*V```#0V`Y`.P!"5ZJ#```[($),K8```-#8"8`[`$)7JH,``#L@0
MDRM@```T-@*@#L`0E>J@P``.R!"3*V```#0V`B`.P!"5ZJ#```[($),K8```
M-#8`D`[`$)7JH,``#L@0DRM@```T-@(`#L`0E>J@P``.R!"3*V```#0V`G`.
MP!"5ZJ#```[($)-KPC_9-]X!`#?</JEKQC\9:\4_(0-@"*5KQ#\I-\0^L6O#
M/S$WPSZY#)D2@`@$`EEKV#ZI"!P"6`QZ$H#H7QL="`,"6B.-```B;0``-YP%
M.#9S!4`/@!"8#F`0FNA"#T`(&`)9*V```$`F!0B0P#``Z``"4BM@``!(/`2X
M#X4`DPQ@$)I"?`;\UY\<'F)\!OPW10`&UY\8`C=:``B#7(+P(RT@`.A?&[77
M6@A"#(`0GP@<`E</X!"3*V````^3$H`T(04@#&`0E@P\$H`CBP``-YP*,"M@
M```._!*(-"$`*`P@$)P._!*0(XL``#><"CB.PD)H#OP2F#03``(V_``8#_,@
ME0N3"I0V<P`"BM,_W0Z5$H`VU@`&"O8*EB.-```.P!*`-YP%2"M@```/@!"9
M-",%*`@%`E@,8!":Z%\6Q6O`/YF3@#``Z``!$NA?&P4,8!":(TL```@<`D0W
MV3\1Z$`$J#=:!2B'@"#H*V```.A?%\4,8!":Z%\8!0@``D!+QC\92\4_(0@$
M`EQ+PC[92\0_*4O#/S'H0,``-]X_`>A?&OT(``)`*V```#0A!2@,/!*`AX`@
M\`@<`EKH7Q4E"``"0"M@``!(/`2X#X4`G.@?'3UCA@S,Z%\8_0Q@$)KH'Q[/
M-"4%&`R@$)J'0"`8-]D_$>A`&]P(``)`Z!\>WR-+``#H0`-@-UH$8`R\$H"'
M@#ZU"!P"6N@?'Z\C2P``-SD`(.A?%`4W6@B8Z!\=S306``CH7Q,=-!H``@@`
M`D`/P!*9:\(_V3?>`(`/WA*9:],_P6O7/Y$C;2``-WL"0"-+``!+6@-X-!<`
M`#06``!KUC^9:]X_B>A?%14(``)`!`````@``D!KPC_9;\0`@&O#/XDK8```
M2#P$J`^`$(.$8"!`"!,"1&O3/\'H0@L8"`,"6H>`(!@(!`)3"`,"5NOB"L@(
M'P)"2\(_64O#/XGH0,``3\0_@2M@``!KPC_9-#H`,#?>`(`K8```-#P`,(.:
M(#`CBP``-YP#D`^`$):&P"`82\(_6>OB"C@('P)"2\(_6>A`P``WWC^!*V``
M`&O"/]DT.@`P-]X`@"M@```T.0`P"UD$&=,\'Z+3.1@?"YD*&=,Y'\&'("`P
M(XL``#><`Y@/@!"6AL`@&$O"/UGKX@F("!\"0DO"/UGH0,``-]X_@6O"/]DK
M8```0#P%"F_#`("/@"`@"`$"0^A?'HT(``)`-!P``F!\!0I+PC]9Z$#``$_#
M/X%KPC_92\(_V>@?'LT(``)`"``"0&O"/]EOR0$`:\@_"6O'/Q%KQC\9:\4_
M(6O$/REKPS\QR-HAN`@9`D@K8```-"$$X`P@$(F%("&B#,`0'-.<'_B'@"`@
M-`4``).<('HT'``"DX`@`.@``,H-(!"#A&`@:`@)`D0T!P!Z"`4"6`@&`EGH
M7Q0%"`,"6H^`(!H,HP`<TYP?^`N'.(#H``"Z#(@PHXQ@/ZT(!0)8"`,"7$O"
M/ME+R#\)2\<_$4O&/QE+Q3\A2\0_*4O#/S'H0,``3\D_`0@&`D4,HC`\TYP?
M^).3('HT$P`"AX`^_PC%!`6.8#_/#*(P/.@?'MT(Q00%"20$!#2E``+0A!^B
M"*,*`^@?'RT-!!*`Z!\?'0@&`D/H'Q\-"`D"0VO"/]DWW@&`-]D^D6O#/W'H
M7Q4="!H"0\N<H(!+TSZQ(J<@`"*"```*LP(3@G0@$"*%``"*="!82\(^60@#
M`EKH7Q*U-!D`!$O#/W&3G#``-!P``DO"/EGH0,``-]X^@30<``!+PCY92\,_
M<>A`P``WWCZ!:\(_V3?>`8!KQC]Q:\4_>6O$/X%KPS^)R+H@$@R@$!R3@"``
MZ```,DO"/EE+QC]Q2\4_>4O$/X%+PS^)Z$#``#?>/H'H7P]M"``"0,A\/[5+
MPCY9Z%\0C0@#`EK+G"%R0Y,`)C9S/Z6.8"`8-X0`)@R"$!.&8#^U"``"0$.3
M`"8V<S^EDF`P`.@``7+H7Q0M"`4"6@@$`EKH7Q05"!P"1@N&"AKH7Q.%-UH`
M!&O$/Y$T&#__"!P"1&O%/YDT&0`""!P"6B+K``#H7PX]-O<#H`@$`EKH7PR]
M-]D^D8>?(#`(!`):2]P^L2*'(``B8@``"IP"'`N3.(#H``#2Z%\2#0@``D#H
M7PN5"`0"6NA?#QT(`P):RYR^ET.3`";H7Q$M"`,"6NA?"P4(!0):2\8_<4O%
M/WE+PCY92\0_@4O#/XGH0,``-]X^@0R"$!,V<S^ECF`^;0@``D`,A!`<AX`]
MY0@``D#H'QY'Z%\=)0@``D#H'Q\?:\(_V3?>`0!KQC\Q:\4_.6O#/TD(&@)#
M:\D_&6O(/R%KQS\I:\0_00\@$!R3@#!ZMR40`@@9`D7H7Q'M"`4"6C?9/Q$(
M'`)&Z%\9;0@#`EK(G")8*V```.A?$:T(!`):B-R!\$O(/Q$K8```U0@(0C0G
M!.`,8!`<TYP?^(>`(S@T%`!Z@Y0C*@@#`EH/0C`STG,?^))@,`#H```*BG0_
MWP]",#,(>@0:#.`0A#3&``0)!`H$Z%\0?0M&"AJ'@"#H#)P2@`S@$),,8!`<
M-'H``M.5'_@-$P"3-!0`>H*T(%@.?!(`CJ`@(#9U``+H``!(-!P`>H>`(#`V
M=0`"#T`0'`Y\,B+3G!_XBY0_S3=:``(V=0`"-!P`>@Y\$@`T$P``#F4`'`IU
M"A0.G!(`TYP?^(^`/]4V<P`"2\(^V4O)/QE+R#\A2\<_*4O&/S%+Q3\Y2\0_
M04O#/TGH0,``-]X_`303```.90`<"F0*%`Z<$@#3G!_XCX`_U39S``+H'Q]U
M2\(^V30G!.`,X!")#2`0G(>`(2`T&0`0"`0"4S2$``(-)""<CX`_YP@$`E,V
M<P`&US,(0BM@```T(040#"`0G(^`('@T'``"##P2@.A?#DT(&0):RGP^O=4$
M"$(($P):"`D"6>A?!G4("`)8#/P2@`@<`E,*9`J3:\0_$>@?'.4.8!*(Z%\(
M%0@)`EH,_!*`AX`^10@<`E/H'Q^MU00(0N@?'04T&@``Z!\?#0@<`D1KPC_9
M-!@?_C?>(0!KQ3\1"!D"13?9'Q%KQ#\9"!H"1"-+``!KPS\AZ%\,E3=:`["/
M@$`X"!P"0S></_\WU!\1#Y0`$XY@((`(`P)8CX`@:`@<`D,K8```2#P$N`-@
M"+,/DP":"`4"6.A?"W4(!`)92\4_$4O$/QE+PA[92\,_(>A`P``WWA\!"`,"
M6#09`%[H7PMU-]H?$8>`/VT(`P)7*V```$@\!+@#8`BS#Y,`F@@$`EGH7PH5
M-]@?$4O%/Q%+Q#\92\(>V4O#/R'H0,``-]X?`2.-```WG`4@:\(_V0^`$)AO
MQ`"`(NT``",K``!KPS^)*V```$@D!+@#8`BC#(,`FC;W!9#H7P0=-SD#T&O`
M/Y$CC0``-YP%*`^`$)@BZP``(RL``#;W"B@W.00(:]<_F>A?"8T,@P":2\,_
MB4O"/UGH0,``3\0_@2.-```WG`4P#X`0F&O"/]DK8```2#P$N`-@"+,/DP":
M-]X`@"+M```C*P``-O<%D.A?`S4W.0/02\(_6>A`P``WWC^!*\$``&O"/]DT
M/@$`:\,_&>A?"I4(``)`(FL``#9S!%!KW#^9-!@@`C09``)KTS^1-]H?$R+K
M``#H7P3U-O<$.",^S_\T&"``-SD_$#?:'Q/H7PDE"]D*&<A\0)`T$P``Z%\)
MI31Z``+*?"!`"!,"6@@#`E@C/L__-SD_$.A?!84+V0H9"!P"4PA\"AP/@!(`
M"!,"7$O#/QDKWO__-#X/`$O"/]GH0,`"2\,_&0@3`EPKWO__-#X/`$O"/]GH
M0,`":\(_V4O"/]GH'QYE"``"0`@``D!KPC_9-]XB`&O%/T$(&@)%(TL``&O$
M/TDW6@1@:\,_40@9`D-KSS[Q:\X^^6O-/P%KS#\):\L_$6O*/QEKR3\A:\@_
M*6O'/S%KQC\YZ%\0/3?9'A$T&0!>"!P"1.A?![4(!0):DX`P`.@``*((!0)9
M(TL``.A?%>4W6@1X"`4"7$O"'=E+SS[Q2\X^^4O-/P%+S#\)2\L_$4O*/QE+
MR3\A2\@_*4O'/S%+QC\Y2\4_04O$/TE+PS]1Z$#``#?>'@$(`P):Z%\#[2#+
M```TV028Z%\?(0@<`EK(?#\=(0L``"#K```,8!`<-`D?_C?,/XDWRS^1-0@$
ML#?*/YDTYP2@-\X^,8>`(;@AIR``A(`@(`@#`EGH7P)="`0"6H>`(5`TV028
MZ%\&[0@#`EHT%0!>-Y,__PIC"A.(<Z`@"!P"3^@``$HV<S__"',X@.@``!H.
M8!`4TI0?^(*5/\\.8!(`Z%\&=0@#`EH('`)/Z%\&70@%`EH)_`H<-YP``H.)
MG=4T&0`"#842@#?:'A$-:!*`"`<"5S08(`#H7P"-#4,2@#?9/A'H7Q\)-]H>
M$8^`(#`TV028#<`0G")D```)O`(<@Y,@L#09``(TV028Z%\=*30:``#(?#TM
M"`4"60Q@$!R/@#Y-"``"0(2`(!H,@!`<-YP_I9.`,`#H```:(&L``#0/``+H
M'Q[%-&,$6`R"$!R'@#]M--D$F.@?'\4@:P``Z%\!_3?:'A&/@#\]--D$F#?9
M'A$C2P``Z%\273=:!'CH7P#U-]H>$>@?'&U+PAW9:\(_V309`%YOPP"`Z%\`
ME0@:`D,WF@`"DX`P``@#`EKH7P"5"``"0$O"/UGH0,``3\,_@6O"/]DWWB$`
M:\4_$6O$/QEKPS\AR+HA0@R@$!R3@#``Z``!*NA?`^4(``)`-!,@`#>8``*#
M$X%8"!P"0S?$'Q$(!0)9Z%\?00@$`EHT?#__"X0*'(B<H"@T%`!>Z```0#09
M`%XWG#__@)P@*#09`%X/@!`3TG,?^()T/\\/@!(`-!D`7NA?'SD(!`):RYP@
M6"-+```(G*B`Z```@NA?'S$(!`):2\4_$4O$/QE+PA[92\,_(>A`P``WWA\!
M(TL``.A?'NDW6@182\4_$4O$/QE+PA[92\,_(>A`P``WWA\!Z!\?;0^`$@`T
M'```2\(>V4O%/Q%+Q#\92\,_(>A`P``WWA\!:\(_V2M@```WW@$`:\0_.30D
M!.!KPS]!(&L``#1C!+AKR#\9:\<_(6O&/REKQ3\Q-]D_$>A?"5T(`P):AX`@
M<$O3/Q$,@!"<"Y,*G`^($).&8#^U#Y,2@`^0$),/DQ*(CF`_Y3><``@WV3\1
MZ%\([0@#`EJ/@#^52],_$2!K```K8```-&,$T#0D!.`WV3\1Z%\(I0@#`EJ'
M@"!P2],_$0R`$)P+DPJ<#X@0DX9@/[4/DQ*`#Y`0DP^3$HB.8#_E-YP`"#?9
M/Q'H7P@U"`,"6H^`/Y5+TS\1(&L``"M@```T8P3@-"0$X#?9/Q'H7P?M"`,"
M6H>`('!+TS\1#(`0G`N3"IP/B!"3AF`_M0^3$H`/D!"3#Y,2B(Y@/^4WG``(
M-]D_$>A?!WT(`P):CX`_E4O3/Q$@:P``*V```#1C!/@T)`3@-]D_$>A?!S4(
M`P):AX`@<$O3/Q$,@!"<"Y,*G`^($).&8#^U#Y,2@`^0$),/DQ*(CF`_Y3><
M``@WV3\1Z%\&Q0@#`EJ/@#^52],_$2!K```K8```-&4%"#0D!.`WV3\1Z%\&
M?0@%`EJ'@"!P2],_$0R`$)P+DPJ<#X@0DX9@/[4/DQ*`#Y`0DP^3$HB.8#_E
M-YP`"#?9/Q'H7P8-"`4"6H^`/Y5+TS\1((L``"M@```TA`4H-"4$X#?9/Q'H
M7P7%"`0"6H>`('!+TS\1#*`0G`N3"IP/B!"3AF`_M0^3$H`/D!"3#Y,2B(Y@
M/^4WG``(-]D_$>A?!54(!`):CX`_E4O3/Q$@BP``*V```#2&!&`T)03@-]D_
M$>A?!0T(!@):AX`@<$O3/Q$,H!"<"Y,*G`^($).&8#^U#Y,2@`^0$),/DQ*(
MCF`_Y3><``@WV3\1Z%\$G0@&`EJ/@#^52],_$2"K```K8```-*<%0#0F!.`W
MV3\1Z%\$50@'`EJ'@"!P2],_$0S`$)P+DPJ<#X@0DX9@/[4/DQ*`#Y`0DP^3
M$HB.8#_E-YP`"#?9/Q'H7P/E"`<"6H^`/Y5+TS\1(,L``"M@```TR`58-"<$
MX#?9/Q'H7P.="`@"6H>`('!+TS\1#.`0G`N3"IP/B!"3AF`_M0^3$H`/D!"3
M#Y,2B(Y@/^4WG``(-]D_$>A?`RT("`):CX`_E4O3/Q$@ZP``*V```#3G!7`T
M*`3@-]D_$>A?`N4(!P):AX`@<$O3/Q$-`!"<"Y,*G`^($).&8#^U#Y,2@`^0
M$),/DQ*(CF`_Y3><``@WV3\1Z%\"=0@'`EJ/@#^52],_$2#K```K8```-.<$
M>#0H!.`WV3\1Z%\"+0@'`EJ'@""`-]D_$4O3/Q$-`!"<"Y,*G`^($).&8#^M
M#Y,2@`^0$),/DQ*(CF`_Y3><``@WV3\1Z%\!M0@'`EJ/@#^52],_$3?9/Q$C
M2P``Z%\!A3=:!8@('#)9Z```"NA?!UTTV@58-]D_$2-+``#H7P%%-UH%L,L\
M(!(C2P``Z%\''3=:!=@WV3\1(TL``.A?`04W6@7P"!PR6>@``&KH7P;=-)H$
M8#1Z!0@C*P``2\(^V4O(/QDW.08X2\<_(4O&/RE+Q3\Q2\0_.4O#/T'H'P9]
M-]X_`3?9/Q$C2P``Z%\`93=:!A#+/#]_-'H%".A?!CTTN@5`Z!\?731Z!0AK
MPC_9(TL``#?>`(`W6@5`Z%\`!3?9/Y'+G"`R#X`0'#03``+3G!_XDX`@`).<
M,&`T'``""GP"G$O"/UGH0,``-]X_@6O"/]DWW@"`:]<_(3?7/SEKV#\I:]D_
M,0[Z$H`(&@)8*V```#0A!0!KUS^1#"`0FNA?%TDT&0`"Z%\/030:`?X(``)`
M:\(_V2O(```T'``$-#X!`&O-/RDT%P``-!@``&O+/SDWS3^9"!H"2VO&/V%K
MQ3]I:\X_(6O,/S%KRC]!:\D_26O(/U%KQS]9:\0_<6O#/WGH7Q0I#;P2@+>F
M!_\('`4%T+T<'PNE`I4+I@*6"!T"7`@=`E,+M@06"Y4%%=+5&_`+M0*4"[0$
M'0N3!1P+I@0&"X4%!8R@8?@AB```(YC/_RM@```WG#\1-`X``#6,`!`+G@H$
M-`H`$#0I`!`T!S__(1C/_PVN$H`(!0)7"`8"6.A?$RD("P):AY\AJ`@,`E@(
M!`)9Z%\.40@+`EJ3@#?_Z``!8H^.@0`WG#_Q"X0*`XB#@!@("@)8Z```VH"#
M@-`("@)8"`D"6>A?#RD(`P):CX`_SS1C/_\(@P0#"`,"7=!\'!\+I@8="X4'
M'$O./R%+S3\I2\P_,4O+/SE+RC]!2\D_24O(/U%+QS]92\8_84O%/VE+Q#]Q
M2\,_>2O7__\T/@\`2\(_V>A`P`((R`8&"*<'!8R_/G\-KA*`(YC/_XC</F<-
MKA*`-!P__S0=/__H'Q\U2\X_(2-+``#H7QP5-UH&8(^_/DT(``)`(TL``.A?
M&^TW6@9`"``"0&O"/]DWW@"`Z%\/00@``D#H7PZY"!P"6LN<(`(/@!"<2\(_
M6>A`P``WWC^!:\(_V3?>`0`WV3\1:\4_(2"K``!KQ#\I"!H"1&O&/QEKPS\Q
MZ%\:V32Z!GC(?"`2#&`0').`(`#H``!""`0"632Z!GA+PC[92\8_&4O%/R%+
MQ#\I2\,_,>@?`&TWWC\!Z%\2P0@$`EH(`P):Z%\2J0@<`D8+A@H:Z%\2&3=:
M``1KPS^)(FL``#9S!)AKQ#^9"!P"0S09``)KTS^1(NL``#08/_\V]P2@Z%\,
MN0@<`EKH'Q\5"`,"66O"/]DCBP``-]X"@#><!JAKR#\Q*W_O_VO'/SDT(0,@
M(0L``&O&/T$WQCZA"!H"1VO%/TDWQ3ZY-]D]D6O$/U$WQ#YQ"`0"56O2/N$U
M&@1@:]$^Z6O0/O%KSS[Y:\X_`6O-/PEKS#\1:\L_&6O*/R%KR3\I:\,_60R\
M$H`CBP``-YP$6`R\$H@T'``@#"@0LPPH$+0.LQ*HKY%?W0ZT$J@CBP``-YP&
MN`S<$H`CBP``-YP&R`R@$I`,P!*0Z%\8.0S<$HC(?"`2#&`0').`(`#H``D:
MZ%\+X0@``D#H7PM9"!P"6LN<)(H/@!"#D&`P`.@`!'+H7Q`I"`,"6M=<""'H
M7P^9-UH``@Q@$!,('`)*TG,?^(9@*,`('`))(6L``#?&/YDU:P;@-`T__S0,
M``+2<QOX"`H"6@S3$H`("P)7"`T"6`@,`EGH7PH)-4H`!`QB,#/2<Q_XCF`_
MK=)S&_@CBP``Z```$#>:!=B30#``Z```<NA?%LDWV3V1R'P_UPR(,+H,8!`<
MAX`_OPR(,+KH7QBY"`,"6H>`/Y\,B#"ZZ%\+$0@#`EH('")#Z```8@R@$(.$
M8"!2#&`0'-.<'_B3@#``Z``#6NA?&$D(`P):CX`C$#2E``@,H!"#C&`_MPQ@
M$!P(`P):Z%\.03?,/X$("0):Z%\.*0@<`D0+A`H$-(0("`@$`EKH7PV)-\L_
MB0V)$H`B:P``-G,'"`US$H`WRC^1(2L``#4I!+`-21*`"!P"1309``(('`):
M#,,2@"+K```T&#__Z%\("3;W!O`T&0.`Z%\&L0@%`EJ/GR`P-]D]D>A?"O$(
M``)`#X`0G#03`"*+DR5R-]D]D>A?#"D(!0):R'R@."M@```WS3VQ(H<@``V@
M$)PB8@``"IP"'`N3.(#H``&J-"$%``S%$H`,X!"7(PL```P@$)HW&`>0Z%\%
MB309``(T!```"`0"7$O"/5E+TC[A2]$^Z4O0/O%+SS[Y2\X_`4O-/PE+S#\1
M2\L_&4O*/R%+R3\I2\@_,4O'/SE+QC]!2\4_24O$/U%+PS]9Z$#``#?>/8'H
M7P@9"``"0,A\NY4(``)`-,8`"`S`$)J30#``Z``$BNA?$SDWV3V1RUP_SS3&
M``@/0!`<CX`_C0@``D#H'Q^E-,8`".A?!Y$(`P):R'P\CPR@$(/H'QSE"`,"
M6N@?',T('`)#Z%\&B4O./<&)W#XU*V````V@$)PT$P.`TYP;]XN3/A4T(04`
MZ%\*40@$`EHWV3V1(TL```@<`D3H7Q)!-UH(.`@<,EGH``.RZ%\!10S@$)H(
M'#).Z``#DNA?"F$(#@):CX:`<`@<`DTWFC_Y(RL```M."AKH7P5Y-SD(2).`
M(`#H```RA:@E$`FN"@TT$P!>#;<0'-.<'_@+DSB`Z``$XB#K```WV3V1Z%\1
M833Z!4#+G"+J#X`0$])S'_B&8"+8-!D``))S,&`T$P`"DF`@`.@``K(T^@5`
M(RL``#<Y!CCH7Q;I(.L``.A?"1DTYPHH#8<2@"+K```-?!*`-O<(H#08/_\-
M21*`-!D``@@$`EH,Q1*`(:L``.A?`VDT#@.`-`\`(C?2/WDUK0C`-!$__^@`
M`(@T$``"Z%\&20@``D`/@!"<"X\H@.@``(+H7PA1-&,``@Y'$H`-@Q*`"`T"
M5PU\$H`($0)8"!`"60U)$H`(!`):Z%\"L0S%$H`(#@)9Z%\!60@$`EJ'GS]5
M"``"0.A?`$D(!0):-1H$8.A?%7$(!`)9Z%\4/0@$`EKH'QL]"`0"7`U<$H`K
M8```-#P%``S@$)<C"P``#,42@#<8!Q@/@!":Z%\`8309``+H'QK5-`0``.A?
M$[T(`P):Z%\#>0@#`EKH'QJE"!P"1.@?%[TWQC^9-!H`&NA?!HD@:P``-&,&
MF`@<`DH('`))Z!\6]303`*;H'QQ=#.`0CC09``#H7P,9"`X"6LF\/34T^@5`
MZ%\/%0@-`EH('`)/C>!]!0@=`E"V&`?M"`\%%P@-`EKH7P.I#,`2@#?./M$T
M&``,"`T"6NA>'M4(#@)9CXPAH".:``@-P!"3-YP"AHI\/(TT^@5`(X(```W(
M$%,WG!"*BGP\;2,K``"V&`>="`\%%P@-`EHT`P``Z%\"^0S#$H`T&`!0-]D]
MD>A>'BT(#0):-!,`4(N3(/`CBP``-YP**`V<$H`WW#V1#7P2@#08/_\-21*`
M(NL``#09``)CPSWA-O<(@`@$`EKH7A^-#,42@.@?'/<,Z!"'A.`[#R#K``#H
M7P31"`<"6H^&FN\@ZP``-YP_^2,K```+APH:Z%X?[3<Y"%B3@#``"`<"3N@?
M&J4@ZP``(TL``.A?#%TW6@AH"``"0"M@``!(/`2X:\(_V3?>`0!KPS\I(TL`
M`&O%/QD#8`BC:\0_(0^#`(0WV3\1-UH%"$"<`-#H7PN!8)P`TLN<("(/@!`3
M-!0`8M)S'_@*=#B`Z``"ZNA?`74(``)`*V```$@\!+@/@P"$(RL``#07``8T
M&``"-SD)`.A>'/4(!`):RYP@:#>$`"!+G``@(PL```^`$)DK8```2"4$N`RC
M`)KH7P%1-Q@)"`R`$)P/@!"9#S`0G-.`W3_H``)R*V```$@E!+@,HP":(RL`
M`#07``8T&``"Z%X</3<Y"1C(G"!"(TL``#?9/Q'H7PH9-UH$>,L<(<A(G``@
M#*,`FNA?`)D/@!"9*V```$@D!+@,@P"%-!@``@@%`EHC*P``Z%\!<3<Y"2`(
M!0):"!P"62,+``#H7P`Q-Q@)4`R#`)PWV3\18X``TB-+``#H7PE9-UH$8"M@
M```T)`48#)P2@(>`('@('`)#-!D#@.A>&L4(`P):-Y,``HYB@"!+PC[9DY,@
M(C03``*.8"#P"!P"5TO%/QE+Q#\A2\,_*>A`P``WWC\!*V```#0A!2`,(!":
MZ%\.U0@``D`,G!*`CX`_30@<`D,C2P``Z%X913=:"6`/@A`<AX`]+2,K``#H
M'QSO*V````^`$)HT(04@#"`0G.A?$FD/@!"9Z!\>%^A>&KT,HP":Z!\=;RM@
M```T/`4@#X`0G"-+```/@!"9"`,"6.A>&)4W6@FH"``"0&O"/]DWW@$`-]D_
M$6O#/R$(&@)#(TL``&O$/QGH7P=A-UH%0,N<(%(/@!`<TYP?^).`(`"3G#!@
M-!P``H^`("A+PC[9A&`@&@Q@$!R3@"``Z```(DO"/ME+Q#\92\,_(>A`P``W
MWC\!Z%\:\0@#`EHT&0!>"!P"1.A>&R4('`):-YH``I.`,``(!`):Z%X;)0@`
M`D`C*P``-!@`"#<Y!PCH7AM-"!P"6H^`/U5+PC[9"`,"6DO$/QE+PS\AZ!\)
M,3?>/P$(``)`:\(_V0@:`E\WW@>`-U0`<#?3.)%KTC[):]$^T0@3`EPW5P#P
M:]`^V30=``!KSS[A:\X^Z6O-/O%KS#[Y:\L_`6O*/PEKR3\1:\@_&6O'/R%K
MQC\I:\4_,6O$/SEKPS]!#H`0E@Z($)4WG``@-I0`$`^6$HD/@!*!#YT2D8KT
M/[T/E1*9-\8XL4O-.6%+S#EI-]4Y$4O+.7%+RCEY-]0YD39R!`!+P3F!2]PY
MB30=``!+QSC!2\4XR4O$.-%+PSC92\(XX4O:..E+V3CQ2]@X^4O1.0%+T#D)
M#,`0B>@``!`,R!"("!<"40@6`E`.H!"7#J@0E@@<`DX(`0)/#F`0G`YH$($*
M_`*<"L$"@0F\`IP)@0*!#IT2@`D!`H$)/`*<"#P"7-`\"!P.G!*("`L"30@*
M`DP(!P))"`4"2`@$`D<(`P)%"`("1`@:`D,(&0)""!@"6@@1`ED($`)8"!T"
M039S`!`VM0`0-I0`$`@/`DN*<C[="`X"2C?Y`"`/X!"+#^@0C$O7.,%+V#C)
M-^,`0&O9/>D,8!")#&@0B@@+`D()@@)9:\D]H6O*/:D,P!"1#,@0DB*3.U`T
M$P``-I0#,FO7/H%KV#Z)2\4XX4O&..G1F0B8"!T"5TO)./%+RCCY2]DY@4O:
M.8DWX0`P"8("0FO#/;E+PSC12\0XV=&""Z(('0)':\,^06O$/DE+PSF12\0Y
MF30<``!KQ3XQ:\8^.4O%.)%+QCB9:\D^(6O*/BE+R3VA2\H]J6O9/@%KVCX)
M"-0&&@BS!QD+2@8:"RD'&4OU`"!+]@`H"QH&&`KY!Q=+[P`P2_``.`_P$(T/
M^!".:\,]T6O$/=D)]0*#"A8"A`FC`AEKT3Z1:](^F0G$`@1+T3D!2](Y"0GY
M`HD*!`**:]$^$6O2/AE+T3EQ2](Y>0L*!@H*Z0<)2]<Y84O8.6G16AB;:]<^
M86O8/FE+USBA2]@XJ0L4!A@*\P<7:\$]X0G-`EEKT3Y1:](^6='9"[E+PSD1
M2\0Y&0L0!A(*[P<1U0H(I0@9`EAKPSYQ:\0^>0M(`D8(&@)%"%D"F0NU`IH)
M>@(:"KH"FM%*"Z$(&@)#"5D"&@L6`ID)F0(9"MD"F0@9`D0(D@8$"'$'`PB&
M!@H(90<):\D^H6O*/JE+PSZI"QH"B$O)/I%+RCZ9T&,+L=!E&)O4PPBE"50&
M!`DS!P,(!0))")8&!`AU!P,)!`8$".,'`PBF`DI+QSZ!2\@^B0B*!@8(:0<%
M"!T"5VO%/I%KQCZ92\D^F=$C&)L)%`8("/,'!VO#/?EKQSZ!:\@^B3?*/H$-
M0!"##4@0A`B8!@0(=P<#2]@^J=;I"*4-0Q*`#402B`@"`EK1*0NR"!T"1TO)
M/?D((@*""3<"2@L"`@)+USZ!2]@^B0M"`HAKW3Z!"1@&"`CW!P<)"@8*".D'
M"4O(/IG4Z@BE"!T"66O'/J$(`0)&"B$"@0D!`@%+QSY!2\@^20D4!A@(\P<7
M",$"B`@=`D<+&@88"OD'%PD8!AH(]P<92\<^H6O9/I%KVCZ9T4D8FPDG`EI+
MUSZ12]@^F0@)`EDWP3Z1"QH&&`KY!Q<*40*::]<^H6O8/JE+V3ZI"5H"&M%*
M"Z)+USXQ2]@^.=,Y"Z'3*1B;"Q0&&`KS!Q<($0)$U5D(I0HZ`I%KT3Z)2]D^
M@4O:/HD('0)%"P8&!@KE!P4+1@88"R4'%P@)`ED)*@):"QH&"@KY!PE+V3ZI
M:\D^D6O*/ID($@)(2]<^F0A2`I(+,@()2]D^(4O:/BG2]PNQTO(8FP@=`D/5
M5PBE"U0&&`LS!Q=KRCZA"0D"F@@=`ED+!`88"N,'%PM8!A@+-P<72\,^H6O=
M/H$*0P)*"!("20L*!@H*Z0<)2]<^$4O8/AD+%`88"O,'%VO7/J%KV#ZI2]@^
MF0@"`D8((@*:-\(^H0L:`AH,0!"7#$@0F`@=`D<+"`8("N<'!PC:`I=KUSZ)
M2]D^@4O:/HD+2`8:"R<'&=%)&)MKV3ZA:]H^J=1*"*4("0)9"2("6C?7/J$.
MZ!"8#N`0EPL:!A@*^0<7:]<^H6O8/JE+USZIUU<(I0@!`D1KVCZ1"B$"@4O9
M/G%+VCYYTO<+H@E!`@D('0)%TN$8FPM4!A@+,P<7"(D"F@@=`ED+!@88"N4'
M%PM8!A@+-P<72\8^D=%*"[((`0))""8"2@L*!AH*Z0<9:]D^D6O:/IE+R3Z9
M"E$"F&O8/G$($0)(2]$^<4O7.2%+V#DI:]<^@6O8/HD('0)9T2D+H4O8/JD+
M$0(1:]$^<=$J&)M+USZ!2]@^B0L4!A@*\P<7:]<^H6O8/JDWT3ZA2]@^<0D8
M`IH('0)##B`0EPXH$)C5*0BE"P0&!`KC!P,+1`88"R,'%P@*`ED)20):"QH&
M"@KY!PE+V3Z9:\D^H6O*/JD($@)&2]<^J0A2`I(+,@()"!T"6=+W"['2\AB;
M",D"F@@=`D?55PBE2]<Y,4O8.3EKRCZ1"Q0&&`KS!Q<+"`88"N<'%PM8!A@+
M-P<72]D^D0@2`DD*60)*"PH&&@KI!QD((@*8:]@^<4O7.4%+V#E):]<^@6O8
M/HD(`@)$"`$"2$O8/JE+PCYQ"P("`@HA`H%+USZ!2]@^B0L4!A@*\P<7:\(^
M<0@=`D-KUSZA:]@^J4O8/G%KV3Z1:]H^F0B8`IH('0)92]<^H4O8/JE+R3Z9
M"P8&!@KE!P71*AB;:]T^@0M&!A@+)0<7"`H"6=$I"[+420BE"4("6@L:!@H*
M^0<):\D^H6O*/JE+USZIUS<(I=+W"Z)KV3Z12\H^F0@=`ED)00()TN$8FPD)
M`II+USE12]@Y60L4!A@*\P<7"P0&&`KC!Q<+6`88"S<'%P@!`DE+VCZ1"#H"
M2@L*!@H*Z0<)2]<^84O8/FD+%`88"O,'%VO7/I%KV#Z9"!$"1DO8/JD*40*:
M-]$^D0L:`AH.(!"7#B@0F`L(!@@*YP<'"-H"EVO7/HE+V3Z!2]H^B0M(!AH+
M)P<9T4D8FVO9/J%KVCZIUBH(I0@)`ED),0):-]<^H0[H$)@.X!"7"QH&&`KY
M!Q=KUSZA:]@^J4O7/JG75PBE"!("1&O:/I$(4@*22]D^44O:/EG2]PNQ"5("
M"0@=`D72\AB;"U0&&`LS!Q<(B0*:"!T"60L&!A@*Y0<7"U@&&`LW!Q=+QCZ1
M:]T^@=%*"Z$($@))"D8"2@L*!@H*Z0<)2]<^`4O8/@D+%`88"O,'%VO7/I%K
MV#Z9"`("2$O8/JD((@*:-\(^D0L:`AH,0!"7#$@0F`L$!@0*XP<#"1H"EVO7
M/HE+V3Z!2]H^B0M$!AH+(P<9T4D8FVO9/J%KVCZIU$H(I4O7/J%+V#ZI"2("
M6@@)`ED+&@88"OD'%VO7/J%KV#ZI"`$"1DO7/JG75PBE"B$"@6O:/I%+V3W1
M2]H]V=+W"Z()00()"!T"1]+A&)L+5`88"S,'%PC)`IH('0)9"P@&&`KG!Q=+
MQSZ1"U@&&`LW!Q?12@NR"`$"20@G`DH+"@8:"ND'&0I1`I=KUSYQ2]<YH4O8
M.:EKUSZ!:]@^B0@1`D0('0)#2]@^J4O1/G$+$0(1"!("2$O7/H%+V#Z)"Q0&
M&`KS!Q=KT3YQ"!T"1VO7/J%KV#ZI2]@^<6O9/I%KVCZ9")@"F@@=`EE+USZA
M2]@^J4O)/ID+!@8&"N4'!=$I"Z$+1@88"R4'%]$J&)O5*0BE"`H"60E)`EH+
M&@8*"OD'"4O9/IEKR3ZA:\H^J0A2`I<+-P()2](^J0D)`IH('0)92]<YL4O8
M.;D+%`88"O,'%PL$!A@*XP<7"U@&&`LW!Q<('0))""("F=)2"(H+"@8*"ND'
M"0I9`A<(`@)&"-<"FDO7.<%+V#G)"Q0&&`KS!Q<+"`88"N<'%])2"['12@B)
M"B$"DP@)`D0('0)9"U@&&@LW!QD+1`88"R,'%PE3`IIKUSZA:]@^J4O(/JE+
MUSG12]@YV2*/G=HT$P``-I0'0DO2/JD+%`88"O,'%P@=`D4('0)9"P8&!@KE
M!P5+USGA2]@YZ0M&!AH+)0<9"Q0&!`KS!P/12@NB"`$"6`@=`E<('0))T0@(
MB@M*!@H+*0<)")@&&@AW!QG1"`NG:]D^D6O:/IE+USZ12]@^F0A1`H@('0)9
M"D@"F@@=`D/12@B&"QH&&`KY!Q=+V3GQ2]HY^0@&`D0+!`88"N,'%VO7/J%K
MV#ZI2\@^J0M4!@0+,P<#".("B0@=`ED)20*:"!T"5P@1`E@(F`88"'<'%PL:
M!A@*^0<72]DZ`4O:.@G12@NET0@+I@@=`D/1"`B("`@"1`L$!@H*XP<)"!T"
M5PM4!AH+,P<9"*<"D0@"`E@+6`8:"S<'&4O7/JD*\0*1"!$"1#07```T&```
M"T0&&@LC!QE+PSH12\0Z&0B4!@0(<P<#"`<"6`B8!A@(=P<7-`,``#0$``#1
M2@NH",4"AP@=`E$)1P*'T4H(D@@'`D0+4@82"S$'$0L$!A@*XP<7"!P"6=)2
M")H+&@8*"OD'"0D&`HE+V3HA2]HZ*0@<`E<+5`8:"S,'&0@%`E@('`)#"U@&
M&@LW!QD*20*)"`D"1`M$!AH+(P<9TE(+O4O#.C%+Q#HY"Z@"B0@<`E'12@B2
M"4D"B0M2!A(+,0<1")0&&@AS!QG12@NB"!P"0P@)`D0(!@)8"U@&&`LW!Q<(
M'`)9"P0&&`KC!Q?24@B:"QH&"@KY!PE+V3I!2]HZ20@<`E<+5`8:"S,'&0A=
M`HD("`)8"DD"B0M8!AH+-P<9"`D"1`M$!AH+(P<9TE(+I4O#.E%+Q#I9"*("
MB0@<`E'12@B2"4D"B0M2!A(+,0<1")0&&@AS!QG12@NF"!P"0P@)`D0('0)8
M"U@&&`LW!Q<('`)9"P0&&`KC!Q?24@B:"QH&"@KY!PE+V3IA2]HZ:0@<`E<+
M5`8:"S,'&0C%`HD(`@)8"DD"B0M8!AH+-P<9"`D"1`M$!AH+(P<9TE(+ITO#
M.G%+Q#IY".8"B0@<`E'12@B2"4D"B0M2!A(+,0<1")0&&@AS!QG12@N]"!P"
M0P@)`D0(!0)8"U@&&`LW!Q<('`)9"P0&&`KC!Q?24@B:"QH&"@KY!PE+V3J!
M2]HZB0@<`E<+5`8:"S,'&0NG`HD(!@)8"DD"B0M8!AH+-P<9"`D"1`M$!AH+
M(P<9TE(+HDO#.I%+Q#J9"%T"B0@<`E'12@B2"4D"B0M2!A(+,0<1")0&&@AS
M!QG12@NE"!P"0P@)`D0(!P)8"U@&&`LW!Q<('`)9"P0&&`KC!Q?24@B:"QH&
M"@KY!PE+V3JA2]HZJ0@<`E<+5`8:"S,'&0BB`HD('0)8"DD"B0M8!AH+-P<9
M"`D"1`M$!AH+(P<9TE(+IDO#.K%+Q#JY"!P"4=%*")((Q0*)"U(&$@LQ!Q$)
M20*)")0&&@AS!QG12@NG"!P"0P@)`D0(`@)8"U@&&`LW!Q<('`)9"P0&&`KC
M!Q?24@B:"QH&"@KY!PE+V3K!2]HZR0@<`E<(Y@*)"DD"B0@)`D0+5`8:"S,'
M&0@%`E@+6`8:"S<'&0M$!AH+(P<92\,ZT4O$.MG24@N]"!P"40NG`HC12@B2
M"4@"B`M2!A(+,0<1")0&&@AS!QD("`)$T4H+H@@<`D,(70**"`8"6`I*`HH+
M6`88"S<'%P@<`ED+!`88"N,'%])2")H("@)$"QH&!@KY!P5+V3KA2]HZZ0@<
M`E<+5`8:"S,'&0@'`E@+6`8:"S<'&0M$!AH+(P<92\,Z\4O$.OD(E`88"','
M%VO7/J%KV#ZI2\,^H4O$/JG24@NI"!P"4=#&")(('`)7"U(&$@LQ!Q$('0)8
MTD48F]3R"*4(F`88"'<'%PBG`EH('`)#"2("G0@%`ED(W0*="!T"1`L$!A@*
MXP<7"QH&!`KY!P,('`)9:\,^H6O$/JE+USL!2]@["0@"`EI+PSZITE(+JM#&
M"ZC09!B;"`@"1@D)`H<+%`88"O,'%PE(`D@+&@88"OD'%PI'`I0)1@(:"&@"
M&0@<`E,+%`84"O,'$]!C"[W40PBE"UD"2`B"`E((!`)12\,[$4O$.QD*D@82
M"G$'$6O#/J%KQ#ZI(IVQXS03``!+V3ZA2]H^J3:4";AKR3Z9"U0&&@LS!QEK
MW#Z1"YP"`VO9/J%KVCZI2]D^D4O:/IDWP3ZATE$8FVO#/H%+PSZA2\0^J0B:
M!@0(>0<#U#((I6O(/HE+V3Z!2]H^B0M$!@0+(P<#"B$"2&O#/J%KQ#ZI-]H^
MH0@1`D</0!"##T@0A`@*`E@(B`8$"&<'`P]#$H`/1!*(2]D^J0NJ`AH+J@)*
M"DH""M,Y"['24@NBTR$8FP@<`D4+2@)(2\D[(4O*.RG660BE"YP"!PE4!AH)
M,P<9"T8&&@LE!QD)&@8("/D'!P@R`DH(`0))"0H&&@CI!QE+QSLQ2\@[.6O'
M/H%KR#Z)-\8^@0S`$(<,R!"("10&"`CS!P<,QQ*`#,@2B`S`$(4,R!"&"!P"
M5PC8!A@(MP<7:]D^D6O:/IE+Q3ZI2\D^F0A=`@'1*0NRT2H8FP@=`D0+G`('
M"%T"7=4I"*4(O0(="4D"1@@]`D@("@)%"1@&"`CW!P<(`@):"08&"@CE!PE+
MQSZ9:\D^H6O*/JD*(@(&2\4^J0HB`D)+R3M!2\H[20CB`@+0I0N]T*$8FP@<
M`D,(P@)("YP"!]1%"*4)5`8&"3,'!0C$!@8(HP<%"08&"`CE!P=+PSM12\0[
M60@!`DD((@)*"0H&`@CI!P$*40((:\$^D6O"/IE+R3Z9-\$^@0@<`EEKR#YQ
M")0&"`AS!P=KQSZ!:\@^B0P@$(,,*!"$")H&!`AY!P/1*0NB#",2@`PD$HC1
M*AB;2\0^J0I1`EG5*0BE")D"&0E)`DD($0)8"YP"!TO1/G$("@)#"CD"2`P@
M$)D,*!":"`D"1`D:!@@(^0<'"00&"@CC!PD($@)&:\D^H6O*/JE+QSZ92\,^
MJ4O).V%+RCMI"[("!`NR`E((\@(2")("2-!C"[$('0):T&$8FPN<`@?60PBE
M"%T"70E4!@0),P<#"!P"5P@R`DH(F`88"'<'%P@!`DD)&`88"/<'%TO(/JD+
M"@88"ND'%PD=`@$*(@)7TQ@+O=58"*4+L0)(:\H^D0L7`@33$AB;:\0^@4O7
M/`%+V#P):\@^<0L4!@0*\P<#"%H""DO'.W%+R#MY"!P"10D4!@@(\P<':\H^
MH0D&!@@(Y0<':\,]P6O$/<E+Q3OQ2\8[^0@"`D0+G`()2\(^H0A!`DH)2`8*
M"2<'"0C4!@@(LP<'2\(^D6O'/=%KR#W9"!$"1@I"`D@($@)'"4@&"`DG!P<(
MQ`(*T0@+HFO*/E$(70)'2\H^<0D*`A)KQSYA:](^D4O).X%+RCN)T1$8FS?2
M/J%KR3ZA:\H^J=0H"*4.0!"'#D@0B`D4!@@(\P<'#D<2@`Y($HA+R#Y1"!P"
M60N<`@E+TCZ!"1("2DO'/J%+R#ZI"1H&"`CY!P<WTCZA"4@&&@DG!QD.61*`
M#EH2B$O'/J%+R#ZI"B$"2@@1`DD)"@8*".D'"0@=`DC14AB;"08"$6O2/?G4
M*@BE:]$^H=%*"[U+T3YA:\$^<0E1`A(+H@)!:](^44O1.Y%+TCN9"!P"0P@<
M`D5KT3YA:](^:0N<`A$('`)':\$]\4O)/F%+RCYI"50&"@DS!PDWP3YA#"D2
M@`PJ$HA+RCZA"!P"60@<`E=+P3Z1"4$"4DO)/F%+RCYI"40&"@DC!PD*2@8$
M"BD'`S?!/J%+T3OA2]([Z0PC$H`,)!*("E0&"@HS!PE+Q#YQ:\D^`6O*/@E+
MR3WY"20"2DO#/J%+Q#ZI"(H&"@AI!PG12@NA2](]\0@"`D1KP3YQT5$8FPA(
M`@%KT3YA"5("`M8J"*5KPCWQ2\(^<0A=`DEKT3WY"YP"$6O)/;%+R3NA2\H[
MJ0E4!@H),P<)"48&!@DE!P5+PCY1""("4@I&!@H*)0<)2]$]^6O)/E%KRCY9
M2\D^80DQ`DH('0)&2]$^44O2/ED*2@8*"BD'"=%=&)L(Q`(2T4H+L6O1/L%K
MW3YA2]$]L=>J"*4('`)%:](^40E1`A(('`)!:]T]^4O=/G$('`)#:](]L4O2
M/L$*70)=2]$[L4O2.[EKW3V9-]T^L6O1/K%KTCZY#Z`0B0^H$(H)5`8*"3,'
M"0N<`A$/J1*`#ZH2B$O*/E%+W3WQ"5T"4DO)/K%+RCZY"4@&"@DG!PD*2@8(
M"BD'!VO'/K%KR#ZY2\D^83?=/E%+QSO12\@[V0D4!A((\P<1"D8&"`HE!P=+
MT3ZQ2](^N0^G$H`/J!*(2\@]^0DH`DH*2@82"BD'$6O1/K%KTCZY2\D^N=$I
M"ZK1,AB;2\@^<0@*`D)KRCYQU4D(I6O2/F%+TC[!"%("4@@<`D<)!@(&:\H]
M^4O)/@%+RCX)"4@&"@DG!PEKTCV12]$]P4O2/<D*0@82"B$'$6O)/@%KRCX)
M"YP""6O1/<%KTCW)2](]L0C2`DI+W3ZY2\4[P4O&.\D(U`8&"+,'!0C$!@8(
MHP<%2]$]F4O$/?D+L0(1"48&"@DE!PEKT3WQ2]$^80HD`E()4@8$"3$'`TO*
M/L%KPSYA:\0^:0@*`D0(B`((2\4^:="F&)O0I0N]:\8^H4O!/?%+QSYIU*4(
MI0C%`E$)`0)&2\@]D6O1/JD+H@(2"Z("40A*`@H+G`(%".@"`DO'/E%+R#Y9
M:\4^D0E"`D$+G`(%:\$^F6O%/D%+P3Z12\(^F0C(!@8(IP<%"!P"0TO'/J%+
MR#ZI",@&!@BG!P4(T0(%2\<^`4O(/@D(2`8*""<'"0I%`D%KP3Y)"`8"0@N<
M`@%KP3XAT$<8F]1""*5KQSZ!".("4FO2/HE+P3Z!2\(^B0E"!@@)(0<'2\D]
MT4O*/=D)1`8*"2,'"4O#/D%+Q#Y)"(H&!`AI!P-KPSZA:\0^J=$#&)O4B`BE
M:\,^,0AD`D'0Q@NF:\$^.0C=`D4(W0(1-](^H0D%`@(WRCXQ"B("1&O$/BE+
MP3XA2\(^*0@=`EK1"`N]#D`0APY($(@-0!"1#4@0D@D2!@H(\0<)T4D8FTO#
M/<%+Q#W):\D^$=2J"*4))0)(:\@^&0A$!A(((P<12\<^$4O(/AD+I@(!#_P2
M@`I(!@@*)P<'"`8"6&O'/J%KR#ZI2\D^J0NF`D;12@NB2\<\$4O(/!D/_!*0
M"48""@D4!@8(\P<%:\4^D6O&/IE+Q3Z12\8^F=$R&)O1*0NQ""H"2`N<`@<(
MV@8:"+D'&=4I"*4)&@8&"/D'!0@=`D0($@)'"DD"2`A=`ET(R`8*"*<'"4O%
M/JE+QSPA2\@\*0B]`@9KQSZA:\@^J3?2/J%KQCZ!#D`0A0Y($(8(U`8&"+,'
M!0A$`@$.11*`#D82B$O&/H$()@)("YP"!PY`$(4.2!"&:\D^D6O*/ID(V`88
M"+<'%P@"`EH)&`8&"/<'!4O)/IG1*0N]T2H8F]4I"*4("@)'"4D"2`C(!@H(
MIP<)2\4^F6O)/H%KRCZ)"B("0@HZ`@H(H@()2\4\,4O&/#E+TCZ)"-0&!@BS
M!P4)20)("YP"!P@<`D,(Q`8$"*,'`PD$!@0(XP<#"!P"2=)2"(H(B@8("&D'
M!TO#/HEKQSZA:\@^J0@1`EA+RCZI"!P"60N<`@<+L0)1"'$"$4O#/$%+Q#Q)
M")0&!`AS!P-+TSZITE(+H@@<`E<+N`(2")H&!`AY!P,*40)(2]D\44O:/%D)
M!`8$".,'`PA=`H<*9P*'(I8)3303```VE`.L"U0&&@LS!QD+6`8:"S<'&0@<
M`E'12@B2")(&$@AQ!Q$('`)#TE((B`@'`D0('`)'")H&!`AY!P,(B`8:"&<'
M&6O9/J%KVCZI2\@^J=%*"ZD('`)9"2("EPI7`IH('`)%"!T"1DO7/&%+V#QI
M"Q0&&`KS!Q<+!@88"N4'%PM8!A@+-P<72]D\<4O:/'D+5`8:"S,'&=)2"[W1
M"`NG"!P"4=$(")(+J0*("Q(&$@KQ!Q$('`)7"`("6`M8!A@+-P<72]D^J0LH
M`H@("`)$"!P"0P@<`ED+!`88"N,'%])2")H(_0*("D@"B`@(`D0+&@8""OD'
M`4O9/(%+VCR):\$^H6O"/JD+5`8:"S,'&4O&/JD('`)7"`D"6-#&"(H+6`8:
M"S<'&0@<`DD+1`8:"R,'&4O#/)%+Q#R9"TH&"@LI!PG24@NE2](^J0B4!AH(
M<P<9"*<"B0I)`HD("0)$T,8+H@@<`D,(10*)"!T"6`E)`HD+6`88"S<'%TO9
M/*%+VCRI"P0&&`KC!Q<("0)$T4H+I@M4!AH+,P<9"!P"4=%*")(('`))"Q(&
M$@KQ!Q$('`)7"`<"6-)2"(H+6`8:"S<'&0M$!AH+(P<92\,\L4O$/+D+2@8*
M"RD'"0C"`HD(E`8:"','&0I)`HD("0)$TE(+O0@<`D,+I@*)"`4"6`E)`HD+
M6`88"S<'%P@<`ED+!`88"N,'%]%*")H("0)$"QH&$@KY!Q'12@NG2]D\P4O:
M/,D('`)7"U0&&@LS!QD(`@)8"!P"20M8!AH+-P<9TE((B@M$!AH+(P<92\,\
MT4O$/-D+2@8*"RD'"0C]`HD(E`8:"','&0I)`HD("0)$TE(+I0@<`D,(IP*)
M"`8"6`E)`HD+6`88"S<'%P@<`ED+!`88"N,'%]%*")H("0)$"QH&$@KY!Q'1
M2@NB2]D\X4O:/.D('`)7"U0&&@LS!QD('0)8"!P"20M8!AH+-P<9TE((B@M$
M!AH+(P<92\,\\4O$//D+2@8*"RD'"0A%`HD(E`8:"','&0I)`HD("0)$TE(+
MI@@<`D,(P@*)"`<"6`E)`HD+6`88"S<'%P@<`ED+!`88"N,'%]%*")H("0)$
M"QH&$@KY!Q'12@N]2]D]`4O:/0D('`)7"U0&&@LS!QD(!0)8"!P"20M8!AH+
M-P<9TE((B@M$!AH+(P<92\,]$4O$/1D+2@8*"RD'"0NF`HD(E`8:"','&0I)
M`HD('`)#"`D"1`@"`E@+6`88"S<'%PL$!A@*XP<7TE(+IP@<`EG12@B:"QH&
M$@KY!Q%+USTA2]@]*0L4!@(*\P<!-!<``#08``!KUSZ1:]@^F=%*"Z5KP3ZA
M:\(^J0C]`H1KUSZ!:]@^B0E$`H$WV3Z12]<^H4O8/JEKQCZ9-`D``#0*```/
M*!":#R`0F0L:!A@*^0<7:\$^B=)2"(I+V3Z!2]H^B0L:!A@*^0<7"PH&"@KI
M!PE+V3TQ2]H].0@<`E<(IP*)"DD"B0@)`D0+5`8:"S,'&0@=`E@+6`8:"S<'
M&0M$!AH+(P<92\,]04O$/4G24@NB"!P"40A%`HG12@B2"4D"B0M2!A(+,0<1
M")0&&@AS!QD("0)$T4H+I@@<`D,(!P)8",("APM8!A@+-P<7"D<"APL$!A@*
MXP<7"!P"6=)2")H(!P)$"QH&"@KY!PE+V3U12]H]60@<`E<+5`8:"S,'&0@%
M`E@+6`8:"S<'&0M$!AH+(P<92\,]84O$/6G24@NH"!P"4=%*")(+4@82"S$'
M$0B4!AH(<P<9"!P"0]%)&Z()!@*%"`("6`E%`H4+6`88"S<'%P@%`D0('`)9
M"P0&&`KC!Q?24@B:U&H+W@L:!@(*^0<!:\$^H6O"/JE+W3ZI"2,"6M.B&)L+
M2`*%"!P"5PI%`I@("0)92\D]<4O*/7D('`)#"50&"@DS!PD(!@)$"40&!`DC
M!P,(F`8$"'<'`]4]"*4(`@)%"$D"1@B&!@((90<!2\,]@4O$/8D(E`8$"','
M`])1&Z((C`8,"&L'"]3R"]X('`)3"B<"1@C:`H,+HP*4T%P(D@@<`DG4@@BE
M"`("6`@(`DH+#@88"NT'%PF*!@@):0<'#_@2F$O*/;D)%`8("/,'!]."&)L*
M1`)4"%("4TO"/>E+Q#WA"10&%`CS!Q,/]!*(T[\;HDO'/:%+R#VI#%P2@->]
M"]X('P)3"_T"5`J6!A0*=0<3#%02B`R<$H`($0)%"-`&!@BO!P4,AA*("T@&
M&@LG!QD-7!*`#5H2B$O".%E+TC[)2]$^T4O0/ME+SS[A2\X^Z4O-/O%+S#[Y
M2\L_`4O*/PE+R3\12\@_&4O'/R%+QC\I2\4_,4O$/SE+PS]!Z$#``#?>.(%K
MPC_9-]X`@.A=%O4T&@$`:X``\"+)3.@T%0``-M8&`@^5$H`/EA*((LW=^305
M```VU@<2#Y42D`^6$I@BUK,7-!4``#;6"?QKE0`@:Y8`*"+2(@8T%0``-M8(
M[&N5`#!KE@`X(M<(>S05```VU@/@:Y4`0&N6`$@T%0``-!8``&N5`%!KE@!8
M:Y4`8&N6`&A+PC]9Z$#``#?>/X%KPC_9-U8`4#=?`&!OR@$`:\4_*0@8`D70
MM1P?:\0_,="U"%S7I0AC:\,_.0@:`D1KR3\):\@_$6O'/QEKQC\A#L`0EP[(
M$)@+N`84"Y<'$P_@$(</Z!"(CN`AB`@9`D.#%(%Z#L`2@-9U"&/0O1A=#M02
MB`NS`EW2O!A="Z@&'0N'!QP/_!*`#_T2B#2*`/`-0!":CT`A,#2'`'`T'`!^
MB+Q!JC2E/X$T"`"`T*D;)C4F``+4Q@C&",,*!@@#`ED(!P):"`@"6.A=$%4T
M8P"`Z%X6+0@$`EJ(9C_%"`,"6=4I",8))00%"`4"6`@&`EGH71`%"`<"6@U%
M$H!+PC[92\D_"4O(/Q%+QS\92\8_(4O%/RE+Q#\Q2\,_.>A`P`!/RC\!M0@`
M`@@'!P?H'QYM#L`2@)=&`(`(`P)9",5X@`@%`D8+1PH:Z%T/50@&`E@-0!"<
M"X8*'#03`("+DS\U#5P2@`C%!`4(PPH#Z%X4]0@$`EKH'QY--!P`?N@?'LT(
M`P)&:\(_V304/P%OR@$`-`H`<&O)/PDW*0!P:\0_,0@:`D1KPS\Y"!D"0VO(
M/Q%KQS\9:\8_(6O%/RE+)0!8T+P;F@N)"A-+)@!02R<`8#><``)+*`!HBXI"
MD`YT$@"7F`"`-!D``.A=#RT+B0H:Z%X3[0@#`EH("@)8-!D``.A=#OT("0):
MT0<(]=$'"?0T'```T0<*Y]>5#QC7E`X8UX<-&->(#!AH?`#@T*8(]="F"?0T
M'```T*8*YM>5#QC7E`X8UX8-&->%#!AH?`#HZ%X3+0@#`EH,:!`<#)P2``@#
M`EH,:!!<#)P2`@QL$!4,E1($#&@0E0R5$@8,>!`5#)42"`QX$%4,E1(*#'P0
M%0R5$@P,>!"5#)42#D!U`"@,E1(01'4`*`R5$A)`=0`L#)42%$AT`"@,E!(6
M0'0`.`R4$AA$=``X#)02&D!T`#P,E!(<2',`.`R3$AY`<P!(8),`($1S`$A@
MDP`B0',`3&"3`"1(?`!(Z%T(K6"<`"9+R3\)2\@_$4O"/ME+QS\92\8_(4O%
M/RE+Q#\Q2\,_.>A`P`!/RC\!EY@`<#09``#H70R="XD*&N@?'9W1!PCU*V``
M`$@\!,!KPC_9;\0`@&O3/\'H70FM#X`0ETO"/UGH0,``3\0_@=+`N]_JP,`"
M#MT0E>J@P``.Q!"3:\(_V0@:`EQOQ`"`:\,_B8=?(-AKTS_!-!0?_@M4B(#H
M``"ZQ]K`L`@:`D/48!P>!&,QE)*`,`#H``"*#&`0E-*5&_Z.H"!X2\(_60:#
M,922@#``Z```6@QH$)DWW``>UX`,'0^`$=P,8!"<*V```#><`"!(/P3(@_P@
M*"*'#X$,8!"<2\(_64O#/XGH0,``3\0_@0_Q$)8.V1"<"IP"%R.@#0&"_2`X
M-M4_^3;5`$`.H!"<"IP"%(*=(!(T'#__Z!\?A4O"/UG7O`H?TY0;EM;<"0@+
MM`)4-!T(``NV`A;3G!GP"M0"5-><"7L+E`)<TI09\(:`(!#6W`A"UY\>,=;<
M"$(/^1"<*V````K5"A5(-@2P-K4`$`[<$H@/Z!":#M42@-;?'#_K_QU]"!\"
M0@Q@$)SH'QZ=2\(_66O"/]EOQ`"`:],_P0@3`D1+PC]9"`0"4^A`P`!/Q#^!
M``&RV@`!L7(``@`!```````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/
M1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`
M4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,
M3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L<V5E
M:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%
M30``+W1M<`````!54T52`````%5315).04U%`````"4P,G@`````)7,E<R5S
M)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@``
M``!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,`````5$5-4$1)4@!435``&````'!E<FP`````
M,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#8S````56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@`````M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F
M9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'
M24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@
M*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@
M*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES
M(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@
M>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D[
M"GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M
M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M
M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M
M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*
M;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*
M;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(
M+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C
M:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%
M<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T
M:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:
M25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U
M="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2![
M"G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI]
M(&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I
M;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N
M86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F
M:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C
M86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!
M0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'
M24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL
M97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H
M(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O
M("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM
M>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H
M*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```&QL@`!LSH`
M`;&R``&RH@`!LO(``;%2`$-!0TA%`````6+L``%B\``!9'0``6(T``%D?```
M``!P97)L>'-I+F,``````!.X```3T`@!``@````(```8(```&EP(!``(````
M$```&J@``!KT"`(`"`````@``!KX```;.`@```@````(```;/```&Y`(```(
M````"```&Y0``!O$"`$`"`````@``!O(```;V`@```@````````;W```'.P(
M!P`(````$```'/```!U@"`$`"````!@``!UD```>U`@$``@````8```>V```
M(00(!P`(````$```(0@``"'8"`,`"````A```"'<```B4`@"``@````(```B
M5```(I0(```(````"```(I@``"-4"`$`"```!!```"-8```C:`@```@`````
M```C;```);@(#0`(```"(```);P``"7L"`$`"`````@``"7P```F\`@#``@`
M``(0```F]```*\`(!@`(````$```*\0``"P$"```"`````@``"P(```L2`@`
M``@````(```L3```+A0(#``(```@$```+A@``"Y`"```"`````@``"Y$```N
M^`@$``@````0```N_```-=P($``(````*```->```#@$"`,`"````!```#@(
M```XS`@"``@````0```XT```7$0($``(````>```7$@``%S@"```"`````@`
M`%SD``!>9`@(``@````0``!>:```8"`("``(````$```8"0``&!("`$`"```
M``@``&!,``!@7$@```````````!@8```89@(`@`(````"```89P``&&X"`$`
M"`````@`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````;$Z``&Q2@`!L4(`````````````````````````````
M`````````````0```P$````!```#$0````P``1.X````#0`!89P````9``&P
M`````!L````(````&@`!L`@````<````!`````0``0%H;__^]0`!`_P````%
M``$*]`````8``03T````"@``!($````+````$````!4``````````P`!L2``
M```"```"]````!0````'````%P`!$,0````'``$0B`````@````\````"0``
M``QO___^``$0.&____\````!;___\``!#W8`````````````````````````
M``````````````````````````````````````````````````I005(N<&T*
M```````!92```1JH``&Q(``!&Y0``;$@``$;R``!L2```2'<``&Q(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````Z`$)7JH,``#H@0E>J?']W6@!P>`,#_[MZMON\``;`H```````!L"0`
M`;.X```````!L20``;-L1T-#.B`H1&5B:6%N(#$S+C(N,"TQ.2D@,3,N,BXP
M```````&``````````$P,2XP,0````````8``````````3`Q+C`Q`````"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM
M=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N4$%225-#+G5N=VEN9``N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YD871A
M`"YG;W0`+F)S<P`N8V]M;65N=``N;F]T90``````````````````````````
M```````````````````````````````````+`````0````(``0$4```!%```
M``T```````````````$`````````$P````<````"``$!)````20````D````
M```````````$`````````"8````'`````@`!`4@```%(````(```````````
M````!``````````X````!0````(``0%H```!:````I0````&``````````0`
M```$````-&____8````"``$#_````_P```#X````!@`````````$````!```
M`#X````+`````@`!!/0```3T```&``````<````!````!````!````!&````
M`P````(``0KT```*]```!($```````````````$`````````3F____\````"
M``$/=@``#W8```#`````!@`````````"`````@```%MO___^`````@`!$#@`
M`!`X````4`````<````!````!`````````!J````!`````(``1"(```0B```
M`#P````&``````````0````,````=`````0```!"``$0Q```$,0```+T````
M!@```!<````$````#````'X````!````!@`!$[@``!.X````'```````````
M````!`````````"$`````0````8``1/4```3U```3<@```````````````0`
M````````B@````$````&``%AG```89P````@```````````````$````````
M`)`````!`````@`!8;P``&&\``!!&```````````````!`````````"8````
M`0```$(``:+4``"BU````D``````````#0````0````$````IP````$````"
M``&E%```I10````$```````````````$`````````+$````.`````P`!L```
M`+``````"```````````````!`````0```"]````#P````,``;`(``"P"```
M``0```````````````0````$````R0````$````#``&P$```L!`````8````
M```````````(`````````-8````&`````P`!L"@``+`H````^`````<`````
M````!`````@```#?`````0````,``;$@``"Q(````!@```````````````0`
M````````>0````$````'``&Q.```L3@```(T```````````````(````````
M`.4````!`````P`!LVP``+-L````'```````````````!`````0```#J````
M"`````,``;.0``"SB````#```````````````!``````````[P````$````P
M````````LX@````?```````````````!`````0```/@````'````````````
M`+.H````*```````````````!``````````!`````P````````````"ST```
2`/X```````````````$`````
